@@ -3,6 +3,7 @@ from distutils import log
 import distutils.command.sdist as orig
 import os
 import sys
+import io
 
 from setuptools.compat import PY3
 from setuptools.utils import cs_path_exists
@@ -166,11 +167,8 @@ class sdist(orig.sdist):
         if not os.path.isfile(self.manifest):
             return False
 
-        fp = open(self.manifest, 'rbU')
-        try:
+        with io.open(self.manifest, 'rb') as fp:
             first_line = fp.readline()
-        finally:
-            fp.close()
         return (first_line !=
                 '# file GENERATED by distutils, do NOT edit\n'.encode())
 
